@@ -1,28 +1,28 @@
-if [ ! -f /etc/avahi/avahi-daemon.conf ]
+if [ ! -e /etc/avahi/avahi-daemon.conf ]
 then
     /usr/bin/mkdir -p /etc/avahi
     /usr/bin/cp /etc/defaults/etc/avahi/avahi-daemon.conf /etc/avahi/avahi-daemon.conf
 fi
 
-if [ ! -f /etc/avahi/avahi-dnsconfd.action ]
+if [ ! -e /etc/avahi/avahi-dnsconfd.action ]
 then
     /usr/bin/mkdir -p /etc/avahi
     /usr/bin/cp /etc/defaults/etc/avahi/avahi-dnsconfd.action /etc/avahi/avahi-dnsconfd.action
 fi
 
-if [ ! -f /etc/avahi/hosts ]
+if [ ! -e /etc/avahi/hosts ]
 then
     /usr/bin/mkdir -p /etc/avahi
     /usr/bin/cp /etc/defaults/etc/avahi/hosts /etc/avahi/hosts
 fi
 
-if [ ! -f /etc/avahi/services/sftp-ssh.service ]
+if [ ! -e /etc/avahi/services/sftp-ssh.service ]
 then
     /usr/bin/mkdir -p /etc/avahi/services
     /usr/bin/cp /etc/defaults/etc/avahi/services/sftp-ssh.service /etc/avahi/services/sftp-ssh.service
 fi
 
-if [ ! -f /etc/avahi/services/ssh.service ]
+if [ ! -e /etc/avahi/services/ssh.service ]
 then
     /usr/bin/mkdir -p /etc/avahi/services
     /usr/bin/cp /etc/defaults/etc/avahi/services/ssh.service /etc/avahi/services/ssh.service
